@@ -2,7 +2,7 @@ var texts = {
 "select": "Select",
 "selectall": "Select all",
 "filter": "Filter",
-"clear": "Clear",
+"clear": "Clear filter",
 "opacity": "Opacity",
 "speed": "Speed",
 "period": "Period",
@@ -19,6 +19,7 @@ var texts = {
 "less": "less",
 "Label": "Label",
 "Color": "Color",
+"Size": "Size",
 "Shape": "Shape",
 "selectacolorscalefor": "Select a color scale for",
 "selectacolorfor": "Select a color for",
